@@ -1,4 +1,4 @@
-N=10000
+N_frac = 100
 import numpy as np
 import numpy.linalg as LA
 
@@ -23,7 +23,7 @@ class parameters_for_update:
 
 
     '''
-    def __init__(self,matrices,lamin, rho,typ):
+    def __init__(self,matrices,lamin, rho,typ, eps_L2 = 1e-3):
 
         (self.A, self.C, self.y) = matrices
         self.lamin = lamin
@@ -41,14 +41,14 @@ class parameters_for_update:
         self.lam         = 1.
         self.r           = -self.y
         self.F           = [True] * n
-        self.eps_L2      = 1e-3
+        self.eps_L2      = eps_L2
         if (rho>0):
             for j in range(n):
                 if( abs(self.y[j]) > self.rho ): self.F[j] = False
         elif (rho<0):
             for j in range(n):
                 if( self.y[j] < self.rho ): self.F[j] = False
-        AtA = self.A[self.F].T.dot(self.A[self.F])
+        AtA = self.A[self.F].T.dot(self.A[self.F]) + self.eps_L2*np.eye(d)
         for i in range(d):
             if (self.s[i] == 1. or self.s[i] == -1.):
                 self.activity[i] = True
@@ -70,10 +70,11 @@ class parameters_for_update:
 
 # iteration of the function up to solve the path at each breaking points.
 def solve_path(matrices, lamin, n_active, rho,typ):
+    d = len(matrices[0][0])
     param = parameters_for_update(matrices, lamin, rho,typ)
     BETA, LAM = [param.beta], [param.lam]
     if param.lam < lamin : return BETA,LAM
-    for i in range(N):
+    for i in range(d*N_frac):
         up(param)
         BETA.append(param.beta), LAM.append(param.lam)
         if (n_active > 0  and param.number_act >= n_active) or param.lam == lamin : 
@@ -233,7 +234,7 @@ def up_huber(param):
 
     if (huber_up):
         F[j_switch] = not F[j_switch]
-        M[:d, :][:, :d] = 2 * A[F].T.dot(A[F])
+        M[:d, :][:, :d] = 2 * A[F].T.dot(A[F]) + eps_L2*np.eye(d)
     else:
         # Update matrix inverse, list of rows in C and activity
         for i in range(d):
